@@ -16,7 +16,6 @@
 #'
 #' @examples
 #'
-#' # Example Fuzzy with Discrete Features
 #' set.seed(1) # determining a seed
 #' data(HouseVotes84)
 #'
@@ -38,30 +37,6 @@
 #' head(pred_FNB)
 #' head(Test[, 1])
 #'
-#'
-#' # Example Fuzzy with Continuous Features
-#' set.seed(1) # determining a seed
-#' data(iris)
-#'
-#' # Splitting into Training and Testing
-#' split <- caTools::sample.split(t(iris[, 1]), SplitRatio = 0.7)
-#' Train <- subset(iris, split == "TRUE")
-#' Test <- subset(iris, split == "FALSE")
-#' # ----------------
-#' # matrix or data frame of test set cases.
-#' # A vector will be interpreted as a row vector for a single case.
-#' test <- Test[, -5]
-#' fit_FNB <- FuzzyNaiveBayes(
-#'   train = Train[, -5],
-#'   cl = Train[, 5]
-#' )
-#'
-#' pred_FNB <- predict(fit_FNB, test)
-#'
-#' head(pred_FNB)
-#' head(Test[, 5])
-#'
-#'
 #' @importFrom stats model.extract na.pass sd terms predict
 #'
 #' @export
@@ -70,13 +45,25 @@ FuzzyNaiveBayes <- function(train, cl, fuzzy = TRUE, m = NULL, Pi = NULL) {
 }
 
 #' @export
-FuzzyNaiveBayes.default <- function(train, cl, fuzzy = T, m = NULL, Pi = NULL) {
+FuzzyNaiveBayes.default <- function(train, cl, fuzzy = TRUE, m = NULL, Pi = NULL) {
+
+  if(fuzzy==F){
+    modelo <- e1071::naiveBayes(as.data.frame(train), factor(cl))
+
+    modelo
+    #structure(modelo,
+    #class = "naiveBayes"
+    #)
+
+
+  }else{
+  
 
   # --------------------------------------------------------
   # Estimating class parameters
   train <- as.data.frame(train)
   cols <- ncol(train) # Number of variables
-  if(is.null(cols)){
+  if(is.null(cols) |  length(cols) == 0){
     cols <- 1
   }
   dados <- train # training data matrix
@@ -105,9 +92,6 @@ FuzzyNaiveBayes.default <- function(train, cl, fuzzy = T, m = NULL, Pi = NULL) {
     resul <- FuzzyNaiveBayes.continuo(train, cl, fuzzy = T, m = NULL, Pi = NULL)
   }
 
-
-
-
   # -------------------------------------------------------
   structure(list(
     parametersC = resul$parametersC,
@@ -121,6 +105,9 @@ FuzzyNaiveBayes.default <- function(train, cl, fuzzy = T, m = NULL, Pi = NULL) {
   ),
   class = "FuzzyNaiveBayes"
   )
+
+  }
+
 }
 # -------------------------
 
@@ -265,7 +252,7 @@ FuzzyNaiveBayes.continuo <- function(train, cl, fuzzy = T, m = NULL, Pi = NULL)
   # Estimating class parameters
   train <- as.data.frame(train)
   cols <- ncol(train) # Number of variables
-  if(is.null(cols)){
+  if(is.null(cols) | length(cols) == 0){
     cols <- 1
   }
   dados <- train
